@@ -2,11 +2,10 @@ package String::Numeric::PP;
 use strict;
 use warnings;
 
-use Carp                    qw[croak];
-use String::Numeric::Regexp qw[:all];
+use Carp qw[croak];
 
 BEGIN {
-    our $VERSION   = '0.9_01';
+    our $VERSION   = 0.1;
     our @EXPORT_OK = qw(
       is_numeric
       is_float
@@ -30,8 +29,22 @@ BEGIN {
     *import = \&Exporter::import;
 }
 
+sub INT8_MIN    () { '128' }
+sub INT16_MIN   () { '32768' }
+sub INT32_MIN   () { '2147483648' }
+sub INT64_MIN   () { '9223372036854775808' }
 sub INT128_MIN  () { '170141183460469231731687303715884105728' }
+
+sub INT8_MAX    () { '127' }
+sub INT16_MAX   () { '32767' }
+sub INT32_MAX   () { '2147483647' }
+sub INT64_MAX   () { '9223372036854775807' }
 sub INT128_MAX  () { '170141183460469231731687303715884105727' }
+
+sub UINT8_MAX   () { '255' }
+sub UINT16_MAX  () { '65535' }
+sub UINT32_MAX  () { '4294967295' }
+sub UINT64_MAX  () { '18446744073709551615' }
 sub UINT128_MAX () { '340282366920938463463374607431768211455' }
 
 *is_numeric = \&is_float;
@@ -39,38 +52,52 @@ sub UINT128_MAX () { '340282366920938463463374607431768211455' }
 
 sub is_float {
     @_ == 1 || croak(q/Usage: is_float(string)/);
-    return ( defined $_[0] && $_[0] =~ /\A$Float_re\z/o );
+    local $_ = $_[0];
+    return ( defined && /\A-?(?:0|[1-9][0-9]*)(?:\.[0-9]+)?(?:[eE][+-]?[0-9]+)?\z/ );
 }
 
 sub is_decimal {
     @_ == 1 || croak(q/Usage: is_decimal(string)/);
-    return ( defined $_[0] && $_[0] =~ /\A$Decimal_re\z/o );
+    local $_ = $_[0];
+    return ( defined && /\A-?(?:0|[1-9][0-9]*)(?:\.[0-9]+)?\z/ );
 }
 
 sub is_int {
     @_ == 1 || croak(q/Usage: is_int(string)/);
-    return ( defined $_[0] && $_[0] =~ /\A$Int_re\z/o );
+    local $_ = $_[0];
+    return ( defined && /\A-?(?:0|[1-9][0-9]*)\z/ );
 }
 
 sub is_int8 {
     @_ == 1 || croak(q/Usage: is_int8(string)/);
-    return ( defined $_[0] && $_[0] =~ /\A$Int8_re\z/o );
+    local $_ = $_[0];
+    return ( defined
+          && /\A(-?)(0|[1-9][0-9]{0,2})\z/
+          && ( length $2 < 3 || ( $1 ? $2 le INT8_MIN : $2 le INT8_MAX ) ) );
 }
 
 sub is_int16 {
     @_ == 1 || croak(q/Usage: is_int16(string)/);
-    return ( defined $_[0] && $_[0] =~ /\A$Int16_re\z/o );
+    local $_ = $_[0];
+    return ( defined
+          && /\A(-?)(0|[1-9][0-9]{0,4})\z/
+          && ( length $2 < 5 || ( $1 ? $2 le INT16_MIN : $2 le INT16_MAX ) ) );
 }
 
 sub is_int32 {
     @_ == 1 || croak(q/Usage: is_int32(string)/);
-    return ( defined $_[0] && $_[0] =~ /\A$Int32_re\z/o );
+    local $_ = $_[0];
+    return ( defined
+          && /\A(-?)(0|[1-9][0-9]{0,9})\z/
+          && ( length $2 < 10 || ( $1 ? $2 le INT32_MIN : $2 le INT32_MAX ) ) );
 }
 
 sub is_int64 {
     @_ == 1 || croak(q/Usage: is_int64(string)/);
     local $_ = $_[0];
-    return ( defined $_[0] && $_[0] =~ /\A$Int64_re\z/o );
+    return ( defined
+          && /\A(-?)(0|[1-9][0-9]{0,18})\z/
+          && ( length $2 < 19 || ( $1 ? $2 le INT64_MIN : $2 le INT64_MAX ) ) );
 }
 
 sub is_int128 {
@@ -83,27 +110,40 @@ sub is_int128 {
 
 sub is_uint {
     @_ == 1 || croak(q/Usage: is_uint(string)/);
-    return ( defined $_[0] && $_[0] =~ /\A$UInt_re\z/o );
+    local $_ = $_[0];
+    return ( defined && /\A(?:0|[1-9][0-9]*)\z/ );
 }
 
 sub is_uint8 {
     @_ == 1 || croak(q/Usage: is_uint8(string)/);
-    return ( defined $_[0] && $_[0] =~ /\A$UInt8_re\z/o );
+    local $_ = $_[0];
+    return ( defined
+          && /\A(0|[1-9][0-9]{0,2})\z/
+          && ( length $1 < 3 || $1 le UINT8_MAX ) );
 }
 
 sub is_uint16 {
     @_ == 1 || croak(q/Usage: is_uint16(string)/);
-    return ( defined $_[0] && $_[0] =~ /\A$UInt16_re\z/o );
+    local $_ = $_[0];
+    return ( defined
+          && /\A(0|[1-9][0-9]{0,4})\z/
+          && ( length $1 < 5 || $1 le UINT16_MAX ) );
 }
 
 sub is_uint32 {
     @_ == 1 || croak(q/Usage: is_uint32(string)/);
-    return ( defined $_[0] && $_[0] =~ /\A$UInt32_re\z/o );
+    local $_ = $_[0];
+    return ( defined
+          && /\A(0|[1-9][0-9]{0,9})\z/
+          && ( length $1 < 10 || $1 le UINT32_MAX ) );
 }
 
 sub is_uint64 {
     @_ == 1 || croak(q/Usage: is_uint64(string)/);
-    return ( defined $_[0] && $_[0] =~ /\A$UInt64_re\z/o );
+    local $_ = $_[0];
+    return ( defined
+          && /\A(0|[1-9][0-9]{0,19})\z/
+          && ( length $1 < 20 || $1 le UINT64_MAX ) );
 }
 
 sub is_uint128 {
